package com.ruoyi.model.mapper;

import java.util.List;
import com.ruoyi.model.domain.AppFeedingFood;

/**
 * 喂养要求Mapper接口
 * 
 * @author ruoyi
 * @date 2025-03-08
 */
public interface AppFeedingFoodMapper 
{
    /**
     * 查询喂养要求
     * 
     * @param feedingFoodId 喂养要求主键
     * @return 喂养要求
     */
    public AppFeedingFood selectAppFeedingFoodByFeedingFoodId(Long feedingFoodId);

    /**
     * 查询喂养要求列表
     * 
     * @param appFeedingFood 喂养要求
     * @return 喂养要求集合
     */
    public List<AppFeedingFood> selectAppFeedingFoodList(AppFeedingFood appFeedingFood);

    /**
     * 新增喂养要求
     * 
     * @param appFeedingFood 喂养要求
     * @return 结果
     */
    public int insertAppFeedingFood(AppFeedingFood appFeedingFood);

    /**
     * 修改喂养要求
     * 
     * @param appFeedingFood 喂养要求
     * @return 结果
     */
    public int updateAppFeedingFood(AppFeedingFood appFeedingFood);

    /**
     * 删除喂养要求
     * 
     * @param feedingFoodId 喂养要求主键
     * @return 结果
     */
    public int deleteAppFeedingFoodByFeedingFoodId(Long feedingFoodId);

    /**
     * 批量删除喂养要求
     * 
     * @param feedingFoodIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAppFeedingFoodByFeedingFoodIds(Long[] feedingFoodIds);

    /**
     * 查询服务记录中所有的喂养要求及其食品列表
     *
     * @return 喂养要求集合
     */
    public List<AppFeedingFood> getAppFeedingFoodList();
}
